@@ -29,14 +29,15 @@ module Foundation.Array.Bitmap
     , cons
     ) where
 
-import           Foundation.Array.Unboxed (UArray)
-import qualified Foundation.Array.Unboxed as A
-import           Foundation.Array.Unboxed.Mutable (MUArray)
-import           Foundation.Class.Bifunctor (first, second)
-import           Foundation.Primitive.Exception
-import           Foundation.Internal.Base
-import           Foundation.Primitive.Types.OffsetSize
-import           Foundation.Primitive.Monad
+import           Basement.UArray (UArray)
+import qualified Basement.UArray as A
+import           Basement.UArray.Mutable (MUArray)
+import           Basement.Compat.Bifunctor (first, second, bimap)
+import           Basement.Compat.Semigroup
+import           Basement.Exception
+import           Basement.Compat.Base
+import           Basement.Types.OffsetSize
+import           Basement.Monad
 import qualified Foundation.Collection as C
 import           Foundation.Numerical
 import           Data.Bits
@@ -63,6 +64,8 @@ instance Eq Bitmap where
     (==) = equal
 instance Ord Bitmap where
     compare = vCompare
+instance Semigroup Bitmap where
+    (<>) = append
 instance Monoid Bitmap where
     mempty  = empty
     mappend = append
@@ -100,6 +103,7 @@ instance C.Sequential Bitmap where
     revDrop n = unoptimised (C.revDrop n)
     splitOn = splitOn
     break = break
+    breakEnd = breakEnd
     span = span
     filter = filter
     reverse = reverse
@@ -372,6 +376,9 @@ break predicate v = findBreak 0
                 then splitAt (offsetAsSize i) v
                 else findBreak (i+1)
 
+breakEnd :: (Bool -> Bool) -> Bitmap -> (Bitmap, Bitmap)
+breakEnd predicate = bimap fromList fromList . C.breakEnd predicate . toList
+
 span :: (Bool -> Bool) -> Bitmap -> (Bitmap, Bitmap)
 span p = break (not . p)
 
