@@ -18,20 +18,22 @@ module Foundation.Array.Chunked.Unboxed
 
 import           Data.Typeable
 import           Control.Arrow ((***))
-import           Foundation.Array.Boxed (Array)
-import qualified Foundation.Array.Boxed as A
-import           Foundation.Primitive.Exception
-import           Foundation.Array.Unboxed (UArray)
-import qualified Foundation.Array.Unboxed as U
-import           Foundation.Class.Bifunctor
-import qualified Foundation.Collection as C
-import           Foundation.Internal.Base
-import           Foundation.Primitive.Types.OffsetSize
-import           Foundation.Numerical
-import           Foundation.Primitive.Types
-import           Foundation.Primitive
+import           Basement.BoxedArray (Array)
+import qualified Basement.BoxedArray as A
+import           Basement.Exception
+import           Basement.UArray (UArray)
+import qualified Basement.UArray as U
+import           Basement.Compat.Bifunctor
+import           Basement.Compat.Semigroup
+import           Basement.Compat.Base
+import           Basement.Types.OffsetSize
+import           Basement.PrimType
 import           GHC.ST
 
+import           Foundation.Numerical
+import           Foundation.Primitive
+import qualified Foundation.Collection as C
+
 
 newtype ChunkedUArray ty = ChunkedUArray (Array (UArray ty))
                       deriving (Show, Ord, Typeable)
@@ -41,6 +43,8 @@ instance PrimType ty => Eq (ChunkedUArray ty) where
 instance NormalForm (ChunkedUArray ty) where
     toNormalForm (ChunkedUArray spine) = toNormalForm spine
 
+instance Semigroup (ChunkedUArray a) where
+    (<>) = append
 instance Monoid (ChunkedUArray a) where
     mempty  = empty
     mappend = append
@@ -75,6 +79,7 @@ instance PrimType ty => C.Sequential (ChunkedUArray ty) where
     revDrop = revDrop
     splitOn = splitOn
     break = break
+    breakEnd = breakEnd
     intersperse = intersperse
     filter = filter
     reverse = reverse
@@ -231,10 +236,14 @@ splitAt n c@(ChunkedUArray spine)
                     )
 
 revTake :: PrimType ty => CountOf ty -> ChunkedUArray ty -> ChunkedUArray ty
-revTake n c = drop (length c - n) c
+revTake n c = case length c - n of
+    Nothing -> c
+    Just elems -> drop elems c
 
 revDrop :: PrimType ty => CountOf ty -> ChunkedUArray ty -> ChunkedUArray ty
-revDrop n c = take (length c - n) c
+revDrop n c = case length c - n of
+    Nothing -> empty
+    Just keepElems -> take keepElems c
 
 -- TODO: Improve implementation.
 splitOn :: PrimType ty => (ty -> Bool) -> ChunkedUArray ty -> [ChunkedUArray ty]
@@ -244,6 +253,10 @@ splitOn p = fmap fromList . C.splitOn p . toList
 break :: PrimType ty => (ty -> Bool) -> ChunkedUArray ty -> (ChunkedUArray ty, ChunkedUArray ty)
 break p = bimap fromList fromList . C.break p . toList
 
+-- TODO: Improve implementation.
+breakEnd :: PrimType ty => (ty -> Bool) -> ChunkedUArray ty -> (ChunkedUArray ty, ChunkedUArray ty)
+breakEnd p = bimap fromList fromList . C.breakEnd p . toList
+
 -- TODO: Improve implementation.
 intersperse :: PrimType ty => ty -> ChunkedUArray ty -> ChunkedUArray ty
 intersperse el = fromList . C.intersperse el . toList
