@@ -1,6 +1,8 @@
 {-# LANGUAGE ViewPatterns #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE UndecidableInstances #-}
+{-# LANGUAGE CPP #-}
 module Foundation.Check.Arbitrary
     ( Arbitrary(..)
     , frequency
@@ -9,10 +11,18 @@ module Foundation.Check.Arbitrary
     , between
     ) where
 
-import           Foundation.Primitive.Imports
+import           Basement.Imports
 import           Foundation.Primitive
-import           Foundation.Primitive.IntegralConv
-import           Foundation.Primitive.Types.OffsetSize
+import           Basement.Nat
+import           Basement.IntegralConv
+import           Basement.Bounded
+import           Basement.Types.OffsetSize
+import qualified Basement.Types.Char7 as Char7
+import           Basement.Types.Word128 (Word128(..))
+import           Basement.Types.Word256 (Word256(..))
+#if __GLASGOW_HASKELL__ >= 710
+import qualified Basement.Sized.List as ListN
+#endif
 import           Foundation.Check.Gen
 import           Foundation.Random
 import           Foundation.Bits
@@ -29,11 +39,20 @@ instance Arbitrary Integer where
 instance Arbitrary Natural where
     arbitrary = arbitraryNatural
 
+instance (NatWithinBound Word64 n, KnownNat n) => Arbitrary (Zn64 n) where
+    arbitrary = zn64 <$> arbitrary
+instance KnownNat n => Arbitrary (Zn n) where
+    arbitrary = zn <$> arbitraryNatural
+
 -- prim types
 instance Arbitrary Int where
     arbitrary = int64ToInt <$> arbitraryInt64
 instance Arbitrary Word where
     arbitrary = word64ToWord <$> arbitraryWord64
+instance Arbitrary Word256 where
+    arbitrary = Word256 <$> arbitraryWord64 <*> arbitraryWord64 <*> arbitraryWord64 <*> arbitraryWord64
+instance Arbitrary Word128 where
+    arbitrary = Word128 <$> arbitraryWord64 <*> arbitraryWord64
 instance Arbitrary Word64 where
     arbitrary = arbitraryWord64
 instance Arbitrary Word32 where
@@ -52,6 +71,8 @@ instance Arbitrary Int8 where
     arbitrary = integralDownsize <$> arbitraryInt64
 instance Arbitrary Char where
     arbitrary = arbitraryChar
+instance Arbitrary Char7 where
+    arbitrary = Char7.fromByteMask . integralDownsize <$> arbitraryWord64
 instance Arbitrary (CountOf ty) where
     arbitrary = CountOf <$> arbitrary
 
@@ -62,6 +83,10 @@ instance Arbitrary String where
     arbitrary = genWithParams $ \params ->
         fromList <$> (genMax (genMaxSizeString params) >>= \i -> replicateM (integralCast i) arbitrary)
 
+instance Arbitrary AsciiString where
+    arbitrary = genWithParams $ \params ->
+        fromList <$> (genMax (genMaxSizeString params) >>= \i -> replicateM (integralCast i) arbitrary)
+
 instance Arbitrary Float where
     arbitrary = arbitraryF32
 instance Arbitrary Double where
@@ -89,6 +114,14 @@ instance (Arbitrary a, Arbitrary b, Arbitrary c, Arbitrary d, Arbitrary e, Arbit
     => Arbitrary (a,b,c,d,e,f) where
     arbitrary = (,,,,,) <$> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary <*> arbitrary
 
+instance Arbitrary a => Arbitrary [a] where
+    arbitrary = genWithParams $ \params ->
+        fromList <$> (genMax (genMaxSizeArray params) >>= \i -> replicateM (integralCast i) arbitrary)
+#if __GLASGOW_HASKELL__ >= 710
+instance (Arbitrary a, KnownNat n, NatWithinBound Int n) => Arbitrary (ListN.ListN n a) where
+    arbitrary = ListN.replicateM arbitrary
+#endif
+
 arbitraryInteger :: Gen Integer
 arbitraryInteger =
     -- TODO use the sized parameter
