@@ -12,21 +12,24 @@
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE ConstrainedClassMethods #-}
 {-# LANGUAGE DefaultSignatures #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-}
+{-# LANGUAGE StandaloneDeriving #-}
 module Foundation.Collection.Sequential
     ( Sequential(..)
     ) where
 
-import           Foundation.Internal.Base
-import           Foundation.Numerical.Subtractive
-import           Foundation.Primitive.Types.OffsetSize
+import           Basement.Compat.Base
+import           Basement.Numerical.Subtractive
+import           Basement.Types.OffsetSize
+import           Basement.Types.AsciiString (AsciiString(..))
 import           Foundation.Collection.Element
 import           Foundation.Collection.Collection
 import qualified Foundation.Collection.List as ListExtra
 import qualified Data.List
-import qualified Foundation.Array.Unboxed as UV
-import qualified Foundation.Primitive.Block as BLK
-import qualified Foundation.Array.Boxed as BA
-import qualified Foundation.String.UTF8 as S
+import qualified Basement.UArray as UV
+import qualified Basement.Block as BLK
+import qualified Basement.BoxedArray as BA
+import qualified Basement.String as S
 
 -- | A set of methods for ordered colection
 class (IsList c, Item c ~ Element c, Monoid c, Collection c) => Sequential c where
@@ -34,6 +37,7 @@ class (IsList c, Item c ~ Element c, Monoid c, Collection c) => Sequential c whe
               , ((revTake, revDrop) | revSplitAt)
               , splitOn
               , (break | span)
+              , (breakEnd | spanEnd)
               , intersperse
               , filter, reverse
               , uncons, unsnoc, snoc, cons
@@ -73,6 +77,10 @@ class (IsList c, Item c ~ Element c, Monoid c, Collection c) => Sequential c whe
     break predicate = span (not . predicate)
 
     -- | Split a collection when the predicate return true
+    breakEnd :: (Element c -> Bool) -> c -> (c,c)
+    breakEnd predicate = spanEnd (not . predicate)
+
+    -- | Split a collection when the predicate return true starting from the end of the collection
     breakElem :: Eq (Element c) => Element c -> c -> (c,c)
     breakElem c = break (== c)
 
@@ -101,6 +109,10 @@ class (IsList c, Item c ~ Element c, Monoid c, Collection c) => Sequential c whe
     span :: (Element c -> Bool) -> c -> (c,c)
     span predicate = break (not . predicate)
 
+    -- | Split a collection while the predicate return true starting from the end of the collection
+    spanEnd :: (Element c -> Bool) -> c -> (c,c)
+    spanEnd predicate = breakEnd (not . predicate)
+
     -- | Filter all the elements that satisfy the predicate
     filter :: (Element c -> Bool) -> c -> c
 
@@ -178,19 +190,11 @@ class (IsList c, Item c ~ Element c, Monoid c, Collection c) => Sequential c whe
     -- | Takes two collections and returns True iff the first collection is an infix of the second.
     isInfixOf :: Eq (Element c) => c -> c -> Bool
     default isInfixOf :: Eq c => c -> c -> Bool
-    isInfixOf c1 c2
-        | len1 > len2  = False
-        | otherwise    = loop 0
-      where
-        endofs = len2 - len1
-        len1 = length c1
-        len2 = length c2
-
-        loop i
-            | i == endofs = c1 == c2Sub
-            | c1 == c2Sub = True
-            | otherwise   = loop (succ i)
-          where c2Sub = take len1 $ drop i c2
+    isInfixOf c1 c2 = loop (len2 - len1) c2
+      where len1 = length c1
+            len2 = length c2
+            loop (Just cnt) c2' = c1 == take len1 c2' || loop (cnt - 1) (drop 1 c2')
+            loop Nothing    _   = False
 
     -- | Try to strip a prefix from a collection
     stripPrefix :: Eq (Element c) => c -> c -> Maybe c
@@ -217,6 +221,7 @@ instance Sequential [a] where
     revSplitAt (CountOf n) = ListExtra.revSplitAt n
     splitOn = ListExtra.wordsWhen
     break = Data.List.break
+    breakEnd = ListExtra.breakEnd
     intersperse = Data.List.intersperse
     span = Data.List.span
     dropWhile = Data.List.dropWhile
@@ -240,6 +245,7 @@ instance UV.PrimType ty => Sequential (BLK.Block ty) where
     revSplitAt n = BLK.revSplitAt n
     splitOn = BLK.splitOn
     break = BLK.break
+    breakEnd = BLK.breakEnd
     intersperse = BLK.intersperse
     span = BLK.span
     filter = BLK.filter
@@ -262,6 +268,7 @@ instance UV.PrimType ty => Sequential (UV.UArray ty) where
     revSplitAt = UV.revSplitAt
     splitOn = UV.splitOn
     break = UV.break
+    breakEnd = UV.breakEnd
     breakElem = UV.breakElem
     intersperse = UV.intersperse
     span = UV.span
@@ -287,6 +294,7 @@ instance Sequential (BA.Array ty) where
     revSplitAt = BA.revSplitAt
     splitOn = BA.splitOn
     break = BA.break
+    breakEnd = BA.breakEnd
     intersperse = BA.intersperse
     span = BA.span
     reverse = BA.reverse
@@ -311,6 +319,7 @@ instance Sequential S.String where
     revSplitAt = S.revSplitAt
     splitOn = S.splitOn
     break = S.break
+    breakEnd = S.breakEnd
     breakElem = S.breakElem
     intersperse = S.intersperse
     span = S.span
@@ -329,3 +338,5 @@ instance Sequential S.String where
     isInfixOf  = S.isInfixOf
     stripPrefix = S.stripPrefix
     stripSuffix = S.stripSuffix
+
+deriving instance Sequential AsciiString
