@@ -10,7 +10,6 @@
 --
 {-# LANGUAGE BangPatterns #-}
 {-# LANGUAGE MagicHash #-}
-{-# LANGUAGE UnboxedTuples #-}
 module Foundation.Hashing.SipHash
     ( SipKey(..)
     , SipHash(..)
@@ -19,12 +18,12 @@ module Foundation.Hashing.SipHash
     ) where
 
 import           Data.Bits
-import           Foundation.Internal.Base
-import           Foundation.Primitive.Types.OffsetSize
-import           Foundation.Primitive.Types
-import           Foundation.Primitive.IntegralConv
+import           Basement.Compat.Base
+import           Basement.Types.OffsetSize
+import           Basement.PrimType
+import           Basement.IntegralConv
 import           Foundation.Hashing.Hasher
-import qualified Foundation.Array.Unboxed as A
+import qualified Basement.UArray as A
 import           Foundation.Array
 import           Foundation.Numerical
 import           Foundation.Bits
@@ -93,20 +92,20 @@ newSipState (SipKey k0 k1) = Sip st SipIncremental0 0
                        (k0 `xor` 0x6c7967656e657261)
                        (k1 `xor` 0x7465646279746573)
 
-mix8Prim :: Int -> Word8 -> InternalState -> SipIncremental -> (# InternalState, SipIncremental #)
+mix8Prim :: Int -> Word8 -> InternalState -> SipIncremental -> (InternalState, SipIncremental)
 mix8Prim !c !w !ist !incremental =
     case incremental of
-        SipIncremental7 acc -> (# process c ist ((acc `unsafeShiftL` 8) .|. Prelude.fromIntegral w), SipIncremental0 #)
+        SipIncremental7 acc -> (process c ist ((acc `unsafeShiftL` 8) .|. Prelude.fromIntegral w), SipIncremental0)
         SipIncremental6 acc -> doAcc SipIncremental7 acc
         SipIncremental5 acc -> doAcc SipIncremental6 acc
         SipIncremental4 acc -> doAcc SipIncremental5 acc
         SipIncremental3 acc -> doAcc SipIncremental4 acc
         SipIncremental2 acc -> doAcc SipIncremental3 acc
         SipIncremental1 acc -> doAcc SipIncremental2 acc
-        SipIncremental0     -> (# ist, SipIncremental1 $ Prelude.fromIntegral w #)
+        SipIncremental0     -> (ist, SipIncremental1 $ Prelude.fromIntegral w)
   where
     doAcc constr acc =
-        (# ist , constr ((acc .<<. 8) .|. Prelude.fromIntegral w) #)
+        (ist , constr ((acc .<<. 8) .|. Prelude.fromIntegral w))
 
 mix8 :: Int -> Word8 -> Sip -> Sip
 mix8 !c !w (Sip ist incremental len) =
@@ -190,9 +189,9 @@ mixBa !c !array (Sip initSt initIncr currentLen) =
     goVec ba start = loop8 initSt initIncr start totalLen
       where
         loop8 !st !incr            _     0 = Sip st incr (currentLen + totalLen)
-        loop8 !st SipIncremental0 !ofs !l
-            | l < 8     = loop1 st SipIncremental0 ofs l
-            | otherwise =
+        loop8 !st SipIncremental0 !ofs !l = case l - 8 of
+            Nothing -> loop1 st SipIncremental0 ofs l
+            Just l8 ->
                 let v =     to64 56 (primBaIndex ba ofs)
                         .|. to64 48 (primBaIndex ba (ofs + Offset 1))
                         .|. to64 40 (primBaIndex ba (ofs + Offset 2))
@@ -201,12 +200,12 @@ mixBa !c !array (Sip initSt initIncr currentLen) =
                         .|. to64 16 (primBaIndex ba (ofs + Offset 5))
                         .|. to64 8  (primBaIndex ba (ofs + Offset 6))
                         .|. to64 0  (primBaIndex ba (ofs + Offset 7))
-                in loop8 (process c st v) SipIncremental0 (start + Offset 8) (l - 8)
+                in loop8 (process c st v) SipIncremental0 (start + Offset 8) l8
         loop8 !st !incr !ofs !l = loop1 st incr ofs l
-        loop1 !st !incr _     0 = Sip st incr (currentLen + totalLen)
-        loop1 !st !incr !ofs !l =
-            let (# st', incr' #) = mix8Prim c (primBaIndex ba ofs) st incr
-             in loop1 st' incr' (ofs + Offset 1) (l - 1)
+        loop1 !st !incr !ofs !l = case l - 1 of 
+            Nothing -> Sip st incr (currentLen + totalLen)
+            Just l1 -> let (!st', !incr') = mix8Prim c (primBaIndex ba ofs) st incr
+                        in loop1 st' incr' (ofs + Offset 1) l1
 
     to64 :: Int -> Word8 -> Word64
     to64 0  !v = Prelude.fromIntegral v
@@ -216,9 +215,9 @@ mixBa !c !array (Sip initSt initIncr currentLen) =
     goAddr (Ptr ptr) start = return $ loop8 initSt initIncr start totalLen
       where
         loop8 !st !incr            _     0 = Sip st incr (currentLen + totalLen)
-        loop8 !st SipIncremental0 !ofs !l
-            | l < 8     = loop1 st SipIncremental0 ofs l
-            | otherwise =
+        loop8 !st SipIncremental0 !ofs !l = case l - 8 of
+            Nothing -> loop1 st SipIncremental0 ofs l
+            Just l8 ->
                 let v =     to64 56 (primAddrIndex ptr ofs)
                         .|. to64 48 (primAddrIndex ptr (ofs + Offset 1))
                         .|. to64 40 (primAddrIndex ptr (ofs + Offset 2))
@@ -227,12 +226,12 @@ mixBa !c !array (Sip initSt initIncr currentLen) =
                         .|. to64 16 (primAddrIndex ptr (ofs + Offset 5))
                         .|. to64 8  (primAddrIndex ptr (ofs + Offset 6))
                         .|. to64 0  (primAddrIndex ptr (ofs + Offset 7))
-                in loop8 (process c st v) SipIncremental0 (start + Offset 8) (l - 8)
+                in loop8 (process c st v) SipIncremental0 (start + Offset 8) l8 -- (l - 8)
         loop8 !st !incr !ofs !l = loop1 st incr ofs l
-        loop1 !st !incr _     0 = Sip st incr (currentLen + totalLen)
-        loop1 !st !incr !ofs !l =
-            let (# st', incr' #) = mix8Prim c (primAddrIndex ptr ofs) st incr
-             in loop1 st' incr' (ofs + Offset 1) (l - 1)
+        loop1 !st !incr !ofs !l = case l - 1 of
+          Nothing -> Sip st incr (currentLen + totalLen)
+          Just l1 -> let (!st', !incr') = mix8Prim c (primAddrIndex ptr ofs) st incr
+                      in loop1 st' incr' (ofs + Offset 1) l1
 
 doRound :: InternalState -> InternalState
 doRound (InternalState !v0 !v1 !v2 !v3) =
