@@ -11,8 +11,9 @@ module Foundation.Monad.Reader
     , runReaderT
     ) where
 
-import Foundation.Internal.Base (($), (.), const)
+import Basement.Compat.Base (($), (.), const)
 import Foundation.Monad.Base
+import Foundation.Monad.Exception
 
 class Monad m => MonadReader m where
     type ReaderContext m
@@ -55,6 +56,14 @@ instance MonadThrow m => MonadThrow (ReaderT r m) where
 instance MonadCatch m => MonadCatch (ReaderT r m) where
     catch (ReaderT m) c = ReaderT $ \r -> m r `catch` (\e -> runReaderT (c e) r)
 
+instance MonadBracket m => MonadBracket (ReaderT r m) where
+    generalBracket acq cleanup cleanupExcept innerAction = do
+        c <- ask
+        lift $ generalBracket (runReaderT acq c)
+                              (\a b -> runReaderT (cleanup a b) c)
+                              (\a exn -> runReaderT (cleanupExcept a exn) c)
+                              (\a -> runReaderT (innerAction a) c)
+
 instance Monad m => MonadReader (ReaderT r m) where
     type ReaderContext (ReaderT r m) = r
     ask = ReaderT return
