@@ -1,4 +1,3 @@
-{-# LANGUAGE UnboxedTuples    #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE OverloadedStrings #-}
 
@@ -13,7 +12,7 @@ module Foundation.UUID
 import Control.Monad (unless)
 import Data.Maybe (fromMaybe)
 
-import           Foundation.Internal.Base
+import           Basement.Compat.Base
 import           Foundation.Collection (Element, Sequential, foldl')
 import           Foundation.Class.Storable
 import           Foundation.Hashing.Hashable
@@ -21,10 +20,10 @@ import           Foundation.Bits
 import           Foundation.Parser
 import           Foundation.Numerical
 import           Foundation.Primitive
-import           Foundation.Primitive.Base16
-import           Foundation.Primitive.IntegralConv
-import           Foundation.Primitive.Types.OffsetSize
-import qualified Foundation.Array.Unboxed as UA
+import           Basement.Base16
+import           Basement.IntegralConv
+import           Basement.Types.OffsetSize
+import qualified Basement.UArray as UA
 import           Foundation.Random (MonadRandom, getRandomBytes)
 
 data UUID = UUID {-# UNPACK #-} !Word64 {-# UNPACK #-} !Word64
@@ -67,7 +66,7 @@ toLString uuid = withComponent uuid $ \x1 x2 x3 x4 x5 ->
     hexWord_4 w l = case hexWord32 w of
                     (c1,c2,c3,c4,c5,c6,c7,c8) -> c1:c2:c3:c4:c5:c6:c7:c8:l
     hexWord64_6 w l = case word64ToWord32s w of
-                        (# wHigh, wLow #) -> hexWord_2 (integralDownsize wHigh) $ hexWord_4 wLow l
+                        Word32x2 wHigh wLow -> hexWord_2 (integralDownsize wHigh) $ hexWord_4 wLow l
 
 nil :: UUID
 nil = UUID 0 0
