@@ -1,6 +1,7 @@
 module Fake.Text
     ( Text
     , pack
+    , unpack
     , length
     , splitAt
     , take
@@ -9,19 +10,23 @@ module Fake.Text
     , reverse
     , decimal
     , double
+    , decodeUtf8
     ) where
 
-import Prelude (undefined, Either(..))
+import Prelude (undefined, Either(..), Char)
 
 data Text = Text
 
 pack _      = Text
+unpack :: Text -> [Char]
+unpack _ = undefined
 length      = undefined
 splitAt _ _ = (undefined, undefined)
 take        = undefined
 filter _    = undefined
 reverse     = undefined
 any         = undefined
+decodeUtf8  = undefined
 
 decimal :: Text -> Either a (b, c)
 decimal = undefined
