@@ -8,7 +8,7 @@ import GHC.ST
 
 import Foundation
 import Foundation.Collection
-import Foundation.Primitive.Block (Block)
+import Basement.Block (Block)
 import Foundation.String.Read
 import Foundation.String
 import BenchUtil.Common
@@ -45,17 +45,19 @@ benchsString = bgroup "String"
     ]
   where
     diffTextString :: (String -> a)
+                   -> Maybe (UArray Char -> c)
                    -> (Text.Text -> b)
                    -> [Char]
                    -> [Benchmark]
-    diffTextString foundationBench textBench dat =
-        [ bench "String" $ whnf foundationBench s
+    diffTextString foundationBench utf32Bench textBench dat =
+           [ bench "String" $ whnf foundationBench s ]
+        <> maybe [] (\f -> [bench "String-UTF32" $ whnf f ws]) utf32Bench
 #ifdef BENCH_ALL
-        , bench "Text"   $ whnf textBench t
+        <> [ bench "Text"   $ whnf textBench t ]
 #endif
-        ]
       where
         s = fromList dat
+        ws = fromList dat
         t = Text.pack dat
 
     diffToTextString :: (UArray Word8 -> String)
@@ -74,19 +76,21 @@ benchsString = bgroup "String"
 
 
     diffBsTextString :: (String -> a)
+                   -> Maybe (UArray Char -> d)
                    -> (Text.Text -> b)
                    -> (ByteString.ByteString -> c)
                    -> [Char]
                    -> [Benchmark]
-    diffBsTextString foundationBench textBench bytestringBench dat =
-        [ bench "String" $ whnf foundationBench s
+    diffBsTextString foundationBench utf32Bench textBench bytestringBench dat =
+        [ bench "String" $ whnf foundationBench s ]
+        <> maybe [] (\f -> [bench "String-UTF32" $ whnf f ws]) utf32Bench
 #ifdef BENCH_ALL
-        , bench "Text"   $ whnf textBench t
-        , bench "ByteString" $ whnf bytestringBench b
+        <> [ bench "Text"   $ whnf textBench t
+           , bench "ByteString" $ whnf bytestringBench b ]
 #endif
-        ]
       where
         s = fromList dat
+        ws = fromList dat
         t = Text.pack dat
         b = ByteString.pack $ Prelude.map (fromIntegral . fromEnum) dat
 
@@ -99,20 +103,20 @@ benchsString = bgroup "String"
     allDatSuffix s = fmap (first (\x -> x <> "-" <> s)) allDat
 
     benchLength = bgroup "Length" $
-        fmap (\(n, dat) -> bgroup n $ diffTextString length Text.length dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString length (Just length) Text.length dat)
             allDat
     benchUnpack = bgroup "Unpack" $
-        fmap (\(n, dat) -> bgroup n $ diffTextString (length . toList) (length . Text.unpack) dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString (length . toList) (Just (length . toList)) (length . Text.unpack) dat)
             allDat
     benchElem = bgroup "Elem" $
-        fmap (\(n, dat) -> bgroup n $ diffTextString (elem '.') (Text.any (== '.')) dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString (elem '.') (Just (elem '.')) (Text.any (== '.')) dat)
             allDat
     benchTake = bgroup "Take" $ mconcat $ fmap (\p ->
-        fmap (\(n, dat) -> bgroup n $ diffTextString (take (CountOf p)) (Text.take p) dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString (take (CountOf p)) (Just (take (CountOf p))) (Text.take p) dat)
                 $ allDatSuffix (show p)
             ) [ 10, 100, 800 ]
     benchSplitAt = bgroup "SplitAt" $ mconcat $ fmap (\p ->
-        fmap (\(n, dat) -> bgroup n $ diffTextString (fst . splitAt (CountOf p)) (fst . Text.splitAt p) dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString (fst . splitAt (CountOf p)) (Just ((fst . splitAt (CountOf p)))) (fst . Text.splitAt p) dat)
                 $ allDatSuffix (show p)
             ) [ 10, 100, 800 ]
 
@@ -121,24 +125,24 @@ benchsString = bgroup "String"
             allDat
 
     benchReverse = bgroup "Reverse" $
-        fmap (\(n, dat) -> bgroup n $ diffTextString reverse Text.reverse dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString reverse (Just reverse) Text.reverse dat)
             allDat
 
     benchFilter = bgroup "Filter" $
-        fmap (\(n, dat) -> bgroup n $ diffTextString (filter (> 'b')) (Text.filter (> 'b')) dat)
+        fmap (\(n, dat) -> bgroup n $ diffTextString (filter (> 'b')) (Just $ filter (> 'b')) (Text.filter (> 'b')) dat)
             allDat
 
     benchRead = bgroup "Read"
         [ bgroup "Integer"
-            [ bgroup "10000" (diffTextString stringReadInteger textReadInteger (toList $ show 10000))
-            , bgroup "1234567891234567890" (diffTextString stringReadInteger textReadInteger (toList $ show 1234567891234567890))
+            [ bgroup "10000" (diffTextString stringReadInteger Nothing textReadInteger (toList $ show 10000))
+            , bgroup "1234567891234567890" (diffTextString stringReadInteger Nothing textReadInteger (toList $ show 1234567891234567890))
             ]
         , bgroup "Int"
-            [ bgroup "12345" (diffBsTextString stringReadInt textReadInt bsReadInt (toList $ show 12345))
+            [ bgroup "12345" (diffBsTextString stringReadInt Nothing textReadInt bsReadInt (toList $ show 12345))
             ]
         , bgroup "Double"
-            [ bgroup "100.56e23" (diffTextString (maybe undefined id . readDouble) (either undefined fst . Text.double) (toList $ show 100.56e23))
-            , bgroup "-123.1247" (diffTextString (maybe undefined id . readDouble) (either undefined fst . Text.double) (toList $ show (-123.1247)))
+            [ bgroup "100.56e23" (diffTextString (maybe undefined id . readDouble) Nothing (either undefined fst . Text.double) (toList $ show 100.56e23))
+            , bgroup "-123.1247" (diffTextString (maybe undefined id . readDouble) Nothing (either undefined fst . Text.double) (toList $ show (-123.1247)))
             ]
         ]
       where
@@ -176,6 +180,8 @@ benchsByteArray = bgroup "ByteArray"
     , benchReverse
     , benchFilter
     , benchAll
+    , benchSort
+    , benchSort32
     ]
   where
     diffByteArray :: (UArray Word8 -> a)
@@ -264,6 +270,32 @@ benchsByteArray = bgroup "ByteArray"
                                                     (ByteString.filter (> 100))
                                                     (Vector.filter (> 100)) dat) allDat
 
+    benchSort = bgroup "Sort" $ fmap (\(n, dat) ->
+        bgroup n $
+            [ bench "UArray_W8" $ whnf uarrayBench (fromList dat)
+            , bench "Block_W8" $ whnf blockBench (fromList dat)
+            ]) allDat
+      where
+            blockBench :: Block Word8 -> Block Word8
+            blockBench dat = sortBy compare dat
+            uarrayBench :: UArray Word8 -> UArray Word8
+            uarrayBench dat = sortBy compare dat
+    
+    benchSort32 = bgroup "Sort32" $ fmap (\n ->
+        bgroup (show n) $ 
+            [ bench "Array_W32" $ whnf arrayBench (fromList $ rdWord32 n)
+            , bench "UArray_W32" $ whnf uarrayBench (fromList $ rdWord32 n)
+            , bench "Block_W32" $ whnf blockBench (fromList $ rdWord32 n)
+            ]) [20, 200, 2000]
+      where
+            blockBench :: Block Word32 -> Block Word32
+            blockBench dat = sortBy compare dat
+            uarrayBench :: UArray Word32 -> UArray Word32
+            uarrayBench dat = sortBy compare dat
+            arrayBench :: Array Word32 -> Array Word32
+            arrayBench dat = sortBy compare dat
+
+
 --------------------------------------------------------------------------
 
 benchsTypes = bgroup "types"
