@@ -26,6 +26,8 @@ module Test.Checks.Property.Collection
     , testMonoidProperties
     , testCollectionProperties
     , testSequentialProperties
+    , fromListP
+    , toListP
     ) where
 
 import Foundation
@@ -222,8 +224,10 @@ testSequentialProperties proxy genElement = Group "Sequential"
     , Property "revDrop" $ withElements2 $ \(l, n) -> toList (revDrop n $ fromListP proxy l) === (revDrop n) l
     , Property "revSplitAt" $ withElements2 $ \(l, n) -> toList2 (revSplitAt n $ fromListP proxy l) === (revSplitAt n) l
     , Property "break" $ withElements2E $ \(l, c) -> toList2 (break (== c) $ fromListP proxy l) === (break (== c)) l
+    , Property "breakEnd" $ withElements2E $ \(l, c) -> toList2 (breakEnd (== c) $ fromListP proxy l) === (breakEnd (== c)) l
     , Property "breakElem" $ withElements2E $ \(l, c) -> toList2 (breakElem c $ fromListP proxy l) === (breakElem c) l
     , Property "span" $ withElements2E $ \(l, c) -> toList2 (span (== c) $ fromListP proxy l) === (span (== c)) l
+    , Property "spanEnd" $ withElements2E $ \(l, c) -> toList2 (spanEnd (== c) $ fromListP proxy l) === (spanEnd (== c)) l
     , Property "filter" $ withElements2E $ \(l, c) -> toList (filter (== c) $ fromListP proxy l) === (filter (== c)) l
     , Property "partition" $ withElements2E $ \(l, c) -> toList2 (partition (== c) $ fromListP proxy l) === (partition (== c)) l
     , Property "snoc" $ withElements2E $ \(l, c) -> toList (snoc (fromListP proxy l) c) === (l <> [c])
@@ -278,6 +282,12 @@ testSequentialProperties proxy genElement = Group "Sequential"
         , Property "collection + empty" $ withElements $ \l1 ->
             isPrefixOf (fromListP proxy []) (fromListP proxy l1) === isPrefixOf [] l1
         ]
+    , Group "isInfixOf"
+        [ Property "b isInfixOf 'a b c'" $ with3Elements $ \(a, b, c) -> 
+            isInfixOf (toCol b) (toCol a <> toCol b <> toCol c)
+        , Property "the reverse is typically not an infix" $ withElements $ \a' ->
+            let a = toCol a'; rev = reverse a in isInfixOf rev a === (a == rev)
+        ]
     ]
 {-
     , testProperty "imap" $ \(CharMap (LUString u) i) ->
@@ -285,11 +295,13 @@ testSequentialProperties proxy genElement = Group "Sequential"
     ]
 -}
   where
+    toCol = fromListP proxy 
     toList2 (x,y) = (toList x, toList y)
     toListFirst (x,y) = (toList x, y)
     toListSecond (x,y) = (x, toList y)
     withElements f = forAll (generateListOfElement genElement) f
     with2Elements f = forAll ((,) <$> generateListOfElement genElement <*> generateListOfElement genElement) f
+    with3Elements f = forAll ((,,) <$> generateListOfElement genElement <*> generateListOfElement genElement <*> generateListOfElement genElement) f
     withElements2 f = forAll ((,) <$> generateListOfElement genElement <*> arbitrary) f
     withElements3 f = forAll ((,,) <$> generateListOfElement genElement <*> arbitrary <*> arbitrary) f
     withElements2E f = forAll ((,) <$> generateListOfElement genElement <*> genElement) f
